@@ -89,7 +89,7 @@ class Client:
         if self.provider == Provider.SLACK:
             self.substitutions = _SLACK_SUBSTITUTIONS
         else:
-            self.substitutions: List[Tuple[str,str]] = []
+            self.substitutions = []
 
     def _nickhandler(self, cmd: bytes) -> None:
         _, nick = cmd.split(b' ', 1)
@@ -266,6 +266,24 @@ class Client:
         channel = self.sl_client.get_channel_by_name(channel.decode()[1:])
         self.sl_client.topic(channel, topic.decode()[1:])
 
+    def _kickhandler(self, cmd: bytes) -> None:
+        _, channel, username, message = cmd.split(b' ', 3)
+        channel = self.sl_client.get_channel_by_name(channel.decode()[1:])
+        user = self.sl_client.get_user_by_name(username.decode())
+        try:
+            self.sl_client.kick(channel, user)
+        except Exception as e:
+            self._sendreply(Replies.ERR_UNKNOWNCOMMAND, 'Error: %s' % e)
+
+    def _invitehandler(self, cmd: bytes) -> None:
+        _, username, channel = cmd.split(b' ', 2)
+        channel = self.sl_client.get_channel_by_name(channel.decode()[1:])
+        user = self.sl_client.get_user_by_name(username.decode())
+        try:
+            self.sl_client.invite(channel, user)
+        except Exception as e:
+            self._sendreply(Replies.ERR_UNKNOWNCOMMAND, 'Error: %s' % e)
+
     def _whohandler(self, cmd: bytes) -> None:
         _, name = cmd.split(b' ', 1)
         if not name.startswith(b'#'):
@@ -392,7 +410,7 @@ class Client:
                 msg
             )
 
-    def _joined(self, sl_ev: slack.Join) -> None:
+    def _joined_parted(self, sl_ev: Union[slack.Join, slack.Leave], joined: bool) -> None:
         """
         Handle join events from slack, by sending a JOIN notification
         to IRC.
@@ -406,7 +424,10 @@ class Client:
             return
         name = user.name.encode('utf8')
         rname = user.real_name.replace(' ', '_').encode('utf8')
-        self.s.send(b':%s!%s@127.0.0.1 JOIN :%s\n' % (name, rname, dest))
+        if joined:
+            self.s.send(b':%s!%s@127.0.0.1 JOIN :%s\n' % (name, rname, dest))
+        else:
+            self.s.send(b':%s!%s@127.0.0.1 PART %s\n' % (name, rname, dest))
 
     def slack_event(self, sl_ev: slack.SlackEvent) -> None:
         if isinstance(sl_ev, slack.MessageDelete):
@@ -424,7 +445,9 @@ class Client:
             f = self.sl_client.get_file(sl_ev)
             self._message(f.announce())
         elif isinstance(sl_ev, slack.Join):
-            self._joined(sl_ev)
+            self._joined_parted(sl_ev, True)
+        elif isinstance(sl_ev, slack.Leave):
+            self._joined_parted(sl_ev, False)
         elif isinstance(sl_ev, slack.TopicChange):
             self._sendreply(Replies.RPL_TOPIC, sl_ev.topic, ['#' + self.sl_client.get_channel(sl_ev.channel).name])
 
@@ -446,6 +469,8 @@ class Client:
             b'PART': self._parthandler,
             b'AWAY': self._awayhandler,
             b'TOPIC': self._topichandler,
+            b'KICK': self._kickhandler,
+            b'INVITE': self._invitehandler,
             b'sendfile': self._sendfilehandler,
             #QUIT
             #CAP LS
