@@ -209,6 +209,11 @@ class Join(NamedTuple):
     channel: str
 
 
+class Leave(NamedTuple):
+    user: str
+    channel: str
+
+
 class TopicChange(NamedTuple):
     topic: str
     channel: str
@@ -223,6 +228,7 @@ SlackEvent = Union[
     MessageBot,
     FileShared,
     Join,
+    Leave,
 ]
 
 
@@ -253,6 +259,25 @@ class Slack:
         if not response.ok:
             raise ResponseException(response)
 
+    def kick(self, channel: Channel, user: User) -> None:
+        r = self.client.api_call('conversations.kick', channel=channel.id, user=user.id)
+        response = load(r, Response)
+        if not response.ok:
+            raise ResponseException(response)
+
+    def invite(self, channel: Channel, user: Union[User, List[User]]) -> None:
+        if isinstance(user, User):
+            ids = user.id
+        else:
+            if len(user) > 30:
+                raise ValueError('No more than 30 users allowed')
+            ids = ','.join(i.id for i in user)
+
+        r = self.client.api_call('conversations.invite', channel=channel.id, users=ids)
+        response = load(r, Response)
+        if not response.ok:
+            raise ResponseException(response)
+
     def get_members(self, id_: str) -> Set[str]:
         """
         Returns the list (as a set) of users in a channel.
@@ -566,6 +591,10 @@ class Slack:
                         j = _loadwrapper(event, Join)
                         self._get_members_cache[j.channel].add(j.user)
                         yield j
+                    elif t == 'member_left_channel':
+                        j = _loadwrapper(event, Leave)
+                        self._get_members_cache[j.channel].remove(j.user)
+                        yield j
                     elif t == 'user_change':
                         # Changes in the user, drop it from cache
                         u = load(event['user'], User)
